const { defineConfig } = require("@vue/cli-service");

const path = require("path");
const fs = require("fs");

function resolve(dir) {
    return path.join(__dirname, dir);
}

const Timestamp = new Date().getTime();

module.exports = defineConfig({
    publicPath: process.env.NODE_ENV === "production" ? "/page/embed/" : "./",
    productionSourceMap: process.env.NODE_ENV !== "production",
    outputDir: "dist",
    assetsDir: "static",
    lintOnSave: true,
    devServer: {
        host: "0.0.0.0",
        port: 8080,
        compress: false,
        proxy: {
            "/api": {
                target: "https://webapet.net/api/",
                changeOrigin: true,
                pathRewrite: {
                    "^/api": "",
                },
                secure: false,
            },
        },
    },
    chainWebpack: (config) => {
        config.resolve.alias.set("@", resolve("src"));
        config.resolve.alias.set("@packages", resolve("packages"));

        // 删除预加载和预获取
        config.plugins.delete("preload");
        config.plugins.delete("prefetch");
    },

    configureWebpack: {
        performance: {
            hints: "warning",
            maxEntrypointSize: 50000000,
            maxAssetSize: 30000000,
            assetFilter: function (assetFilename) {
                return assetFilename.endsWith(".js");
            },
        },
    },
    // 以避免构建后的代码中出现未转译的第三方依赖
    transpileDependencies: [/node_modules[/\\\\]/],

    css: {
        extract: {
            filename: `./static/css/[name].${process.env.VUE_APP_VERSION}.${Timestamp}.css`,
            chunkFilename: `./static/css/[name].${process.env.VUE_APP_VERSION}.${Timestamp}.css`,
        },
    },
});